Dispatcher

Struct Dispatcher 

pub struct Dispatcher { /* private fields */ }
Used to call futures from another thread, getting their output values via await.

Implementations

Source

impl Dispatcher

pub fn new() -> Self

pub fn run(&mut self)

Run all tasks in the pool to completion.

This method will not enqueue new tasks until the next call!

pub fn run_until_stalled(&mut self)

Runs all tasks in the pool and returns if no more progress can be made on any task.

This method will not enqueue new tasks until the next call!

pub fn try_run_one(&mut self) -> bool

Runs all tasks and returns after completing one future or until no more progress can be made. Returns true if one future was completed, false otherwise.

This method will not enqueue new tasks until the next call!

pub fn get_handle(&self) -> DispatcherHandle

Get a DispatcherHandle to control this Dispatcher from another thread.

pub fn get_handle_local(&self) -> LocalDispatcherHandle

Get a LocalDispatcherHandle to control this Dispatcher from the same thread.